# monaco-qt

[![license](https://img.shields.io/pypi/l/monaco-qt.svg)](./LICENSE)
[![pypi version](https://img.shields.io/pypi/v/monaco-qt.svg)](https://pypi.org/project/monaco-qt/)
[![PyPI status](https://img.shields.io/pypi/status/monaco-qt.svg)](https://github.com/DaelonSuzuka/monaco-qt/)

The monaco text editor deployed as a Qt Widget.

Uses QWebEngineView to load a custom web page containing an instance of monaco.
